/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, Thomas and Skopek, Jan (2015). Convergence or Continuity? 
  The Gender Gap in Household Labor After Retirement. In: Journal of 
  Marriage and Family.
 
  00_preparation.do
  
  Preparation of the original survey data of the SOEP, version 29. 
  
  Input: Original SOEPlong files (v.29).
  Output: temp/couplehousew.dta (couple data set, long format)
 
  Prepate data to comply with the following format: 
  +-----------------------------------------+
  |          coupleid   syear   sex1   sex2 |
  |-----------------------------------------|
  |   1000903-1000904    2001      1      2 |
  |-----------------------------------------|
  |     100101-100102    1984      1      2 |
  |     100101-100102    1985      1      2 |
  |     100101-100102    1986      1      2 |
  |     100101-100102    1987      1      2 |
  |     100101-100102    1988      1      2 |
  |     100101-100102    1989      1      2 |
  |     100101-100102    1990      1      2 |
  |     100101-100102    1991      1      2 |
  |     100101-100102    1992      1      2 |
  |     100101-100102    1993      1      2 |
  |     100101-100102    1994      1      2 |
  |     100101-100102    1995      1      2 |
  |     100101-100102    1996      1      2 |
  |     100101-100102    1997      1      2 |
  |     100101-100102    1998      1      2 |
  |     100101-100102    1999      1      2 |
  |     100101-100102    2000      1      2 |
  |-----------------------------------------|



  Availability of time use items (H=housework, E=errands, R=repairs, C= childcare)
  (note: until 1990 Housework and Errands have been surveyed together in one item; 
  1984 even together with childcare)			

	1984	H&E&C, R	
	1985	H&E, C, R
	1986	H&E, C, R
	1987	H&E, C, R
	1988	H&E, C, R
	1989	H&E, C, R
	1990	H&E, C, R  
	1991	H, E, R, C
	1992	H, E, R, C
	1993 	H, E, R, C
	1994	H, E, R, C
	1995	H, E, R, C
	1996	H, E, R, C
	1997	H, E, R, C
	1998	H, E, R, C
	1999	H, E, R, C
	2000	H, E, R, C
	2001	H, E, R, C
	2002	H, E, R, C
	2003	H, E, R, C
	2004	H, E, R, C
	2005	H, E, R, C
	2006	H, E, R, C
	2007	H, E, R, C
	2008	H, E, R, C
	2009	H, E, R, C
	2010	H, E, R, C
	2011	H, E, R, C
	2012	H, E, R, C
 
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// configuration file
if "${config}"!="1" do config 


/*-----------------------------------------
  Prepare variables on the household level 
  ("couple level") 
  
  Variables: 
  - living space (square meter)
  - appartment with garden/yard
  - children younger than 16 years present
  - net income
  - NUTS Level 1

  (note: not all variables will be used for the analysis)
-----------------------------------------*/

tempfile hhvars
use hid syear hlk0044 using "${data}/hl", clear

// living space 
merge 1:1 hid syear using "${data}/hgen", keepusing(hgsize hgeqpgar hgnuts1 hgroom hgtyp1hh hgtyp2hh hgi1hinc hgi2hinc hgi3hinc hgi4hinc hgi5hinc) assert(matched) nogen
rename hgsize hqm
lab var hqm "living space (m2)"

// apartment with garden/yeard
recode hgeqpgar (1 = 1) (2 = 0) (-1 = .a), gen(yard)
lab var yard "apartment/house with yard"

// children < 16 years old
gen kind16 = hlk0044
recode kind16 (-1 = .a) (2=0) (1=1)
* fill up 15 missing values with last observation
by hid (syear), sort: replace kind16 = kind16[_n-1] if mi(kind16)
lab var kind16 "children < 16 in hh"


// net income; calculate mean of net income imputations
mvdecode hgi1hinc hgi2hinc hgi3hinc hgi4hinc hgi5hinc, mv(-2 = .b)
egen hgihinc = rowmean(hgi1hinc hgi2hinc hgi3hinc hgi4hinc hgi5hinc)
replace hgihinc = .b if hgihinc == .
drop hgi?hinc
lab var hgihinc "hh net income (mean of imputed values)"

// NUTS level 1
mvdecode hgnuts1, mv(-2 = .b \ -1 = .a)

keep hid syear hqm kind16 yard hgnuts1 hgroom hgtyp1hh hgtyp2hh hgihinc
save `hhvars'

/*-----------------------------------------
  Prepare variables on the person level  
  (Person long file "pl")
  
  Variables: 
	- time use variables, health related variables (satisfaction with health and self-rated health)
	(longitudinal person file, pl)
	- retirement and employment state (calender file pkal)
	- current employment state and educational level (generated variables, pgen)

  (note: not all variables will be used for the analysis)
-----------------------------------------*/


// Note: person long file is huge. Select only relevant variables. 

use pid syear pli0043 pli0041 	/// housework (hours on weekday)
			  pli0040 			/// errands (hours on weekday)
			  pli0044 pli0045 	/// childcare (hours on weekday)
			  pli0047 			/// education and further education (hours on weekday)
			  pli0049 pli0050 	/// repairs, gardening, etc. (hours on weekday)
			  pli0051 			/// hobbies, spare time (hours on weekday)
			  pli0038 pli0037 pli0039 /// job, side-job, training (hours on weekday)
			  plh0171 			/// satisfaction with health
			  ple0008 			/// self-rated health
			  plh0151 plh0182   /// general life satisfaction
			  pli0016 pli0015 pli0017 /// housework (sunday)
			  pli0012 pli0013 pli0014 /// housework (saturday)
			  using  "${data}/pl", clear

count	// 482,288 person-year records
			  
* check consistency of sorting 
isid pid syear

/*-----------------------------------------
  Time use items
-----------------------------------------*/
  
// Notes on coding of time use variables in the SOEP:
// - housework and errands have been asked jointly in one item from survey year 1985-1990
// - in 1984 housework, errands, and child care have been asked jointly (hence, we will exclude year 1984 later for our purpose)
// - housework for housework is provided in two variables pli0041 & pli0043 
//		pli0041 is only available for 1990 and is filled if pli0043 < 0
assert pli0043==-2 if pli0041 > 0
// - repairs: two variables as well: pli0049 pli0050; pli0050 only available for 1990
//	   pli0050 equals pli0049 if pli0050 > 0			
assert pli0049==pli0050 if pli0050>0

// Notes on life satisfaction (general)
//	- plh0182: available from 1984-2012 (not for pile-up samples K & J in 2011/2012)
//	- plh0151: only available for 1988 (not needed, since recoded into plh0182)
tab plh0182 plh0151 if plh0151 >= -1
assert plh0182==plh0151 if plh0151 >= -1
// drop plh0151 
drop plh0151

* recode missings
// Note on missing codes and conversion to stata missings: 
// -5 	not included in questionnaire	==> .b
// -3	not valid						==> .c
// -2/-8	does not apply				==> .b
// -1	not specified					==> .a
mvdecode pl*, ///
		 mv(-1 = .a \ -2 = .b \ -8 = .b \ -5 = .b \ -3 = .c)
		 
// time use: job hours
gen 	hrsjobed = pli0038 	// set pli0038 as default variable
replace hrsjobed = pli0037 if mi(hrsjobed) & !mi(pli0037) // 548 replacements
replace hrsjobed = pli0039 if mi(hrsjobed) & !mi(pli0039) // 0 replacements
* check distributions
tabstat pli0038 pli0037 pli0039 hrsjobed, stat(mean p25 p50 p75 N) col(stats)

drop pli0037 pli0038 pli0039
lab var hrsjobed "time use: job hours (weekday)"
 
// time use: errands
gen hrserr = pli0040 
drop pli0040
lab var hrserr "time use: errands (weekday)"

// time use: hobbies
gen hrshobb = pli0051 
drop pli0051 
lab var hrshobb "time use: hobbies (weekday)"

// time use: further education
gen hrslearn = pli0047 
drop pli0047 
lab var hrslearn "time use: education/further education (weekday)"

// time use: housework
gen hrshw = pli0043 
replace hrshw = pli0041 if mi(hrshw) & !mi(pli0041) // 5539 replacements
* check distributions
tabstat pli0041 pli0043 hrshw, stat(mean p25 p50 p75 N) col(stats)

drop pli0041 pli0043
lab var hrshw "time use: housework (weekday)"

// time use: child care
gen hrscc = pli0044 
replace hrscc = pli0045 if mi(hrscc) & !mi(pli0045) // 3613 replacements
* check distributions
tabstat pli0044 pli0045 hrscc, stat(mean p25 p50 p75 N) col(stats)

drop pli0044 pli0045
lab var hrscc "time use: childcare (weekday)"

// time use: repairs
gen hrsrep = pli0049 
replace hrsrep = pli0050 if mi(hrsrep) & !mi(pli0050) // 2227 replacements
* check distributions
tabstat pli0049 pli0050 hrsrep, stat(mean p25 p50 p75 N) col(stats)

drop pli0049 pli0050
lab var hrsrep "time use: repairs (weekday)"

// health (satisfaction & self-rated)
rename plh0171 hlthsat
lab var hlthsat "health: satisfaction"
rename ple0008 hlthself
lab var hlthself "health: self-rated" // note: self-rated health is surveyed only occasionally 

// general life satisfaction (currently)
rename  plh0182 lifesat

tempfile pl
save `pl', replace

/*-----------------------------------------
  Generated variables on person level ("pgen")
  - educational level
  - employment state (current)
  - effective working hours per week
  - current net income
-----------------------------------------*/
// note: load file with generated person-level variables
use pid syear pgcasmin pgisced /// educational level (CASMIN and ISCED-97 scales)
			  pgemplst /// current employment state
			  pgtatzt  /// effective working hours per week (not contractual hours)
			  pglabnet /// current net income (including imputed values) in Euro
			  using "${data}/pgen", clear

count // 484.170 person-year records			  
			  
* check consistency of sorting
isid pid syear

* recode missings
// Note on missing codes and conversion to stata missings: 
// -5 	not included in questionnaire	==> .b
// -3	not valid						==> .c
// -2/-8	does not apply				==> .b
// -1	not specified					==> .a
mvdecode pg*, ///
		 mv(-1 = .a \ -2 = .b \ -8 = .b \ -5 = .b \ -3 = .c)

tempfile pgen
save `pgen'

/*-----------------------------------------
  Prepare calendar file for reconstructing 
  transition to retirement
  (person calendar file "pkal")
-----------------------------------------*/
	
use pid syear kal1a01 kal1b01 kal1d01 kal1e01 using "${data}/pkal", clear

count // 473.633 person year records

* check consistency of sorting
isid pid syear

* rename variables for employment status (last year, "im Vorjahr")
rename kal1a01 VZ	// note: fulltime
rename kal1b01 TZ	// note: parttime
rename kal1d01 AL	// note: unemployment
rename kal1e01 RE	// note: retirement

mvdecode VZ TZ AL RE, ///
		 mv(-1 = .a)
		 
tempfile pkal
save `pkal', replace

/*-----------------------------------------
  Merge all person level data
  ppfadl (longitudinal path file for persons)
    <-- pgen
	<-- pl
	<-- pkal
-----------------------------------------*/

// start with person path file (includes all sample members)
use pid syear using "${data}/ppfadl", clear

* merge pgen
merge 1:1 pid syear using `pgen', assert(master match) 
gen nogen = _merge==1
drop _merge

* merge pl
merge 1:1 pid syear using `pl', assert(master match) 
gen nopl = _merge==1
drop _merge

* merge pkal
merge 1:1 pid syear using `pkal', assert(master match)
gen nokal = _merge==1
drop _merge

* data overview 
count // 703,274 person-year records
count if nogen==0 // 484,170 with information from pgen
count if nopl==0 // 482,288 with information from pl
count if nokal==0 // 473,633 with information from pkal 
count if nogen==0 & nopl==0 & nokal==0	// 473,633 with information from all person files

* save person data
tempfile person
save `person', replace


/*-----------------------------------------
  Reconstruct married couples and 
  built a couple-year dataset
-----------------------------------------*/
// load person path file (includes all sample members and cursors to partners)
use "${data}/ppfadl", clear

// Note: pid is the unqiue person identifier and parid is the partner cursor (containing the person id of the partner).

* data overview
count // 703,274 person-year records
count if parid < 0 // 321,150 records having no partner cursor

* partnership state
fre partner // 331,891 (47.19%) observations with an identifiable marriage partner (partner = 1)
			// 694 (0.1%) obserations with a probable without certainty marriage partner (partner = 3)
			// rest: 1.4% does not apply; 0.34% not clear; 43.92% no partner in household; 6.88% partner (not married); 0.17% probable without certainty partner (not married) 
			
* keep only relevant variables
keep pid hid sex syear gebjahr wave parid partner iyear psample loc1989

* recode missing values (-2 does not apply; -1 = unclear)
mvdecode parid partner, mv(-1 = .a \ -2 = .)
mvdecode gebjahr , mv(-1 = .a)

// restrict to observations with married partners only 
* keep only cases who have an identifiable SOEP spouse (partner=1 & partner cursor not missing)
keep if inlist(partner,1)  & !mi(parid) 

// Note: that implies for the analysis that we only observe couples over the time they are married.
//		 Consequently, potential couple observations prior to marriage (or after divorce) are ignored. 	 

count // 331,891 person-year records with married partner (47.19% of original data)

// rearrange data matrix to marital couple data (one row = one marital couple-year observation)
* create a mirror data set ("partner" => partner 2) with renamed variables ({varname}2)
* that will be merged to the master dataset (partner 1) later
preserve
	foreach var of varlist * {
		rename `var' `var'2
	}
	* undo renaming for following variables important for merging and
	* interchange variables names for person id and partner id
	rename syear2 syear
	rename pid2 	parid 
 	rename parid2 	pid
	* save mirror file
	tempfile partner
	save `partner'
restore

* renamte variables in the master dataset (partner 1) as well ({varname}1)
foreach var of varlist * {
	rename `var' `var'1
}

* undo renaming for following variables important for merging
rename syear1 	syear
rename pid1 	pid
rename parid1 	parid

* Merge Partner 1 (master) and Partner 2 (mirror)	
merge 1:1 pid parid syear using `partner'

// Note: after merging master and mirror, one row represents a marital couple-year record.
//		 Consider that now each couple is represented twice in the dataset. 
* keep only matched cases
keep if _merge==3

// Note:
// 1 couple pid=30737601 & pid=30737602 is dropped (2 records) since there is contradicting 
// partnership information for partners in survey year 2012 
// (30737601 is non-marital partner for 30737602 and 30737602 is marital partner for 30737601).
// As we cannot decide which is true ex post factum, we remove that couple. 
 
drop _merge

* Now, remove the couple duplicates
assert pid!=parid 	// assert logical condition that nobody is married with himself

* create a couple identifier (by min(pid) and max(pid))
gen minpid = min(pid, parid) 
gen maxpid = max(pid, parid) 
* sort observations by couples
by minpid maxpid syear, sort: gen N = _N 
assert N == 2	// check that all couples are included twice in the data 
drop  N
* drop the couple duplicate
by minpid maxpid syear (pid parid), sort: drop if _n > 1 

* check that couple identifier and survey year uniquely identifies records in the dataset
isid minpid maxpid syear 

* create a identifier variable (string) "coupleid" that uniquely identifies married couples
gen coupleid = string(minpid) + "-" + string(maxpid) 
drop minpid maxpid

* rename person id and partner id to pid1 and pid2 respectively (pid1 = partner 1 and pid2 = partner 2 of couple)
rename pid pid1
rename parid pid2

* improve order of variables
order coupleid syear pid1 *1 pid2 *2

* 165,945 couple year observations; 17531 unique martial couples 
unique coupleid
count

tempfile couples
save `couples'

/*-----------------------------------------
  Merge person level data to couples
-----------------------------------------*/

* save two mirror files, one for partner 1 ("{varname}1") and one for partner 2 ("{varname}2")
forvalues partnernum = 1/2 {
	preserve
		use `person', clear
		foreach var of varlist * {
			rename `var' `var'`partnernum'
		}
		rename syear`partnernum' syear 
		
		* save in temp file p`partner'
		tempfile partner`partnernum' 
		save `partner`partnernum'', replace
	restore
	
	merge 1:1 pid`partnernum' syear using `partner`partnernum'', nogen assert(matched using) keep(matched) 
}

assert hid1 == hid2
rename hid1 hid
drop hid2

* order of variables
order coupleid hid syear *1 *2

/*-----------------------------------------
 merge household level data to couples
-----------------------------------------*/
merge n:1 hid syear using `hhvars',  keep(matched master) nogen


/*-----------------------------------------
  Generate couple variables
-----------------------------------------*/

// retirement indicator
gen MRE = RE1 if sex1==1  
replace MRE = RE2 if sex2==1  
gen FRE = RE1 if sex1==2  
replace FRE = RE2 if sex2==2
* Recode retirement indicators
foreach var of varlist MRE FRE {
	recode `var' (2=0) (1=1)
}
lab var MRE "Man retired (last year)"
lab var FRE "Women retired (last year)"

* VZ (fulltime)
gen MVZ = VZ1 if sex1==1  
replace MVZ = VZ2 if sex2==1  
gen FVZ = VZ1 if sex1==2  
replace FVZ = VZ2 if sex2==2

// educational attainment
* highest casmin (for man and woman)
by coupleid (syear), sort: egen maxcasmin1 = max(pgcasmin1)
by coupleid (syear), sort: egen maxcasmin2 = max(pgcasmin2)

gen Mhcasmin = maxcasmin1 if sex1==1
replace Mhcasmin = maxcasmin2 if sex2==1
gen Fhcasmin = maxcasmin1 if sex1==2
replace Fhcasmin = maxcasmin2 if sex2==2

lab val Mhcasmin pgcasmin
lab val Fhcasmin pgcasmin

drop maxcasmin? 

* highest CASMIN (for couple)
gen Chcasmin = max(Mhcasmin, Fhcasmin)
lab val Chcasmin pgcasmin

lab var Mhcasmin "husband's highest casmin"
lab var Fhcasmin "wife's highest casmin"
lab var Chcasmin "couple's highest casmin"

* highest ISCED (for man and woman)
by coupleid (syear), sort: egen maxisced1 = max(pgisced1)
by coupleid (syear), sort: egen maxisced2 = max(pgisced2)

gen Mhisced = maxisced1 if sex1==1
replace Mhisced = maxisced2 if sex2==1
gen Fhisced = maxisced1  if sex1==2
replace Fhisced = maxisced2 if sex2==2

lab val Mhisced pgisced
lab val Fhisced pgisced

drop maxisced? 

* highest ISCED (for couple)
gen Chisced = max(Mhisced, Fhisced)
lab val Chisced pgisced

lab var Mhisced "husband's highest isced"
lab var Fhisced "wife's highest isced"
lab var Chisced "couple's highest isced"


// current employment state
foreach num of numlist 1/2 {
	recode pgemplst`num' (1 = 1 "Full-time") ///
				 (2 = 2 "Part-time") ///
				 (3/6=3 "marginal/not employed") ///
				 , gen(curempl`num')
	lab var curempl`num' "current employment state (recode of pgemplst)"
}
gen Mcurempl = curempl1 if sex1==1
replace Mcurempl = curempl2 if sex2==1
gen Fcurempl = curempl1 if sex1==2
replace Fcurempl = curempl2 if sex2==2
lab var Fcurempl "wife's current employment state (recode of pgemplst)"
lab var Mcurempl "husbands's current employment state (recode of pgemplst)"
lab val Fcurempl curempl1
lab val Mcurempl curempl1

// current effective working hours (per week)
gen Mcurwkhrs = pgtatzt1 if sex1==1
replace Mcurwkhrs = pgtatzt2 if sex2==1
gen Fcurwkhrs = pgtatzt1 if sex1==2
replace Fcurwkhrs = pgtatzt2 if sex2==2
lab var Mcurwkhrs "husband's current effective working hours (week)"
lab var Fcurwkhrs "wife's current effective working hours (week)"

// health variables (satisfaction & self-rated)
gen Mhlthsat = hlthsat1 if sex1==1
replace Mhlthsat = hlthsat2 if sex2==1
gen Fhlthsat = hlthsat1 if sex1==2
replace Fhlthsat = hlthsat2 if sex2==2
gen Mhlthself = hlthself1 if sex1==1
replace Mhlthself = hlthself2 if sex2==1
gen Fhlthself = hlthself1 if sex1==2
replace Fhlthself = hlthself2 if sex2==2
lab var Fhlthsat "wife's health satisfaction"
lab var Mhlthsat "husbands's health satisfaction"
lab var Fhlthself "wife's self-rated health"
lab var Mhlthself "husbands's self-rated health"
lab val Fhlthsat plh0171
lab val Mhlthsat plh0171
lab val Fhlthself ple0008
lab val Mhlthself ple0008

// life satisfaction
gen Mlifesat = lifesat1 if sex1==1
replace Mlifesat = lifesat2 if sex2==1
gen Flifesat = lifesat1 if sex1==2
replace Flifesat = lifesat2 if sex2==2
lab val Mlifesat plh0182
lab val Flifesat plh0182
lab var Mlifesat "husband's general life satisfaction"
lab var Flifesat "wife's general life satisfaction"

* save couple dataset
save "${tempDir}/couplehousew", replace
