/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, Thomas and Skopek, Jan (2015). Convergence or Continuity? 
  The Gender Gap in Household Labor After Retirement. In: Journal of 
  Marriage and Family.
 
  01_sample.do
  
  Selection of the longitudinal sample. 
  - exclude observations from year 1984
  - exclude homosexuals
  - exclude couples with missing personal questionnaire for either partner
  - exclude cases from high income sample (Sample G)
  - exclude couples where either partner did not live in West-Germany in 1989 
  - conditioning the sample on couples that experience husband's retirement
  - restrict sample to couples where husband is aged >= 50 at year of reported retirement
  - exclude observations more than 10 years before or after husband's reporting of retirement 
 
 Input: temp/couplehousew.dta (see 00_preparation.do)
 Output: temp/01_sample.dta
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// configuration file
if "${config}"!="1" do config 
 
// note: couple data in couple-year long panel format
use "${tempDir}/couplehousew", clear

/*-----------------------------------------
 Sample restrictions
 
  - exclude observations from year 1984
 
  - exclude homosexual couples
  
  - exclude couples with missing personal questionnaire for either partner
  
  - exclude cases from high income sample (Sample G)
  
  - exclude couples where either partner did not live in West-Germany in 1989
-----------------------------------------*/

// remove survey year 1984 (housework, errands and childcare have been asked jointly, which is incompatible with other measures)
drop if syear==1984

* Number of unique values of coupleid is  17405
* Number of records is  161955
unique coupleid

// drop homosexual couples
drop if sex1==sex2	// 113 couple-years removed (30 couples)

unique coupleid	// 17375 couples

// drop records where no information from pl is available for either partner
// (those observations are useless) 
drop if nopl1==1 & nopl2==1	// 12,744 couple-years removed (598 couples lost)

unique coupleid	// 16777 couples

// drop if at least one partner did not fill out the person questionnaire (no pl data for one partner)
drop if nopl1==1 | nopl2==1	// 9,191 couple-years removed (1,130 couples lost)

* Number of unique values of coupleid is  15647
* Number of records is  139907
unique coupleid

// remove Sample G (high income sample; selective and not a random sample)
assert psample1==psample2
drop if inlist(psample1, 7) // 6,417 couple-years removed (1,055 couples lost)

* Number of unique values of coupleid is  14592
* Number of records is  133490
unique coupleid

// restrict to couples only where both spouses lived in west-germany in 1989 
keep if loc19891 == 2 & loc19892 == 2	// 42,620 couple-years removed (5611 couples lost)

* Number of unique values of coupleid is  8981
* Number of records is  90870
unique coupleid


/*-----------------------------------------
  Condition on the retirement event
-----------------------------------------*/

// gen a variable indicating survey year 1990 or before
gen sy1990 = syear <= 1990
lab var sy1990 "Survey year 1990 or before"

// sort properly
sort coupleid syear
li coupleid  syear MRE FRE RE* in 1/100, sepby(coupleid)

// center at male retirement event
by coupleid (syear), sort: gen N = _N
fre N
sum N
local max `r(max)'
di `max'
drop N
gen first = .
foreach num of numlist 1/`max' {
	by coupleid  (syear), sort: replace first = MRE[`num'] if MRE[`num'] < . &  mi(first)
}

sort coupleid syear
li coupleid  syear first MRE RE* in 1/100, sepby(coupleid)

// drop cases for whom we do not know anything about the male retirement 
drop if first == .	// 0 obs deleted

// drop cases where man is retired already at the first observation (left censored cases)
drop if first == 1	// 13,661 observations removed (1,700 couples lost)
drop first

* Number of unique values of coupleid is  7281
* Number of records is  77286
unique coupleid

by coupleid  (syear), sort: gen MREstate = sum(MRE)
replace MREstate = 1 if MREstate > 0 & MREstate < .

// drop cases, where the man does not retire (right censored cases)
by coupleid  (syear), sort: egen maxMREstate = max(MREstate)
drop if maxMREstate == 0	// 48,709 obs removed 
drop maxMREstate
 
li coupleid  syear  MREstate MRE RE* in 1/100, sepby(coupleid)

*  1,617 couples remain
* Number of unique values of coupleid is  1617
* Number of records is  28577
unique coupleid
count  


// mark years prior to male retirement 

* generate a counter variable "years before retirement was reported" 
by coupleid  (syear), sort: gen help = syear if MREstate == 1 & MREstate[_n-1] == 0
by coupleid  (syear), sort: egen help2 = max(help)
by coupleid  (syear), sort: gen index = syear - help2
drop help help2

li coupleid  syear  MREstate MRE index in 1/100, sepby(coupleid)

// we condition on at least 3 observations (one before, one at the time, and one after the year retirement was reported)
by coupleid (syear), sort: egen minindex = min(index)
by coupleid (syear), sort: egen maxindex = max(index)
sort coupleid syear
li coupleid  syear  MRE FVZ MREstate index minindex maxindex in 1/50, sepby(coupleid)
drop if minindex > -1 
drop if maxindex < 1
drop minindex maxindex
* assert consistency; we should always have -1 -> 0 -> 1 observations 
gen one = index==-1
gen two = index==0
gen three = index==1
foreach var of varlist one two three {
	by coupleid (syear), sort: egen max`var' = max(`var')
}
drop if maxone + maxtwo + maxthree < 3
drop maxone maxtwo maxthree one two three
* assert: surveying years sequential and successive? 
assert syear == syear[_n-1]+1 if inlist(index,0,1) & coupleid==coupleid[_n-1]
li coupleid index syear if syear != syear[_n-1]+1 & inlist(index,0,1) & coupleid==coupleid[_n-1]


* Number of unique values of coupleid is  1388
* Number of records is  24984
unique coupleid
count  


/*-----------------------------------------
  Restriction to couples where husband 
  is aged >= 50 at retirement
-----------------------------------------*/

// husband at least in age 50 at year of retirement
gen Mage = syear - gebjahr1 if sex1==1
replace Mage = syear - gebjahr2 if sex2==1

gen helper = Mage if MREstate==1 
by coupleid (syear), sort: egen MageAtRE = min(helper)
* subtract 1 year 
replace MageAtRE = MageAtRE - 1
li coupleid  syear  MRE MREstate index Mage  MageAtRE in 1/50, sepby(coupleid)

// remove couples where man is younger than 50 at time of retirement 
drop if MageAtRE < 50
drop Mage helper

* Number of unique values of coupleid is  1302
* Number of records is  23491
unique coupleid
count  

// catgorial variable "index" for indicating transition phase of retirement  
recode index (-10/-3 = 0 "-10/-3") ///
			 (-2 = 1 "-2") ///
			 (-1 = 2 "-1") ///
			 (0 = 3 "0") ///
			 (1 = 4 "+1") ///
			 (2 = 5 "+2") ///
			 (3/10 = 6 "+3/10") ///
			 (min/-11 = 7 "min/-11") ///
			 (11/max = 8 "11/max"), gen(R)
			 
/*-----------------------------------------
  drop obs more than 10 years before or 
  after transition
-----------------------------------------*/

// drop observations more than 10 years before or after 
drop if index > 10 | index < -10	// 5007 obs removed

* Number of unique values of coupleid is  1302
* Number of records is  18484
unique coupleid
count  

* plot
twoway histogram index, xlabel(-10(1)10) discrete

// recode
recode MVZ (1=1) (2=0) (.=.) 
recode FVZ (1=1) (2=0) (.=.)	

* Number of unique values of coupleid is  1302
* Number of records is  18484
unique coupleid
count  

// save files
save "${tempDir}/01_sample", replace




