/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, Thomas and Skopek, Jan (2015). Convergence or Continuity? 
  The Gender Gap in Household Labor After Retirement. In: Journal of 
  Marriage and Family.
  
  02_impuation.do
  
  Multiple imputation of missing values (step A) and generation of analytical variables (step B). 
  Requires step 01_sample. Executed by master _PROJECT_MASTER_.do

  Step A) Multiple imputation of missing values primiarly in hour variables 
         (but also in all other variables of interest)

  Step B) Generation of analytical variables based on imputations 
		  (like hours for total household labor or husband's share)
 

  We use *chained equations* as method for multiple imputation of missing values.  
  Note: Chained equations is an iterative sequential regression algorithm (Gibbs sampler) 
 	    approximating imputation draws from an (unknown) joint posterior distribution of imputation model variables 
       (Heeringa, West, & Berglund, 2010). 

 Key features of the imputation model we apply:
  - chained equations account for multivariate dependencies between variables to be imputed 
    (e.g. hours variables are correlated)
  - includes not only variables from the analytical model but also additional variables (e.g. job hours, income)
  - accounts for dependency of time varying spouse variables by incorporating a couple model 
   (e.g. female housework hours are regressed not only female working hours but also on male working hours)
  - accounts for time constant heterogeneity between couples (like highest education, age constellation, others) 
    by including fixed couple effects 
    (hence the imputation model is consistent with the fixed effects estimator used in the analytical model)
  - the imputation model applies predictive mean matching (PMM) ensuring that only observable values are imputed (e.g. no negative hours)
    (PMM = observed value from the closest neighbour in predicted mean by linear regression is used for imputing values) 
  - the imputation model accounts for differences by survey year in item formulations regarding hours spent on housework 
    and errands 
  - M=5 imputations are generated to obtain valid inference (in line with suggestions by Rubin 1987 or van Buuren, Boshuizen, and Knook 1999).
 	(our analysis show that relative efficiencies are > 95%)
 
  Note: Imputation can take several hours of computing even in multi-core environments. 
 		By default the script does not re-run the imputation. To change that behavior, set
 		global "runimputation" to 1 (see below). 
 
  Note: For robustness checks we run several imputation models.
        A) "_MI_R"
		mi impute chained (pmm) Fhrshw Fhrsrep  Mhrshw Mhrsrep  ///	
						Mhlthsat Fhlthsat Mlifesat Flifesat  yard ///
						Meffworkhrs ///
						Feffworkhrs ///
				  (pmm if syear > 1990) Fhrserr Mhrserr ///
				  = i.R i.kind16 c.hqm i.syear i.Mcurempl i.Fcurempl ///
					c.Minc c.Finc i.coupleidnum , rseed(123) replace report 
					
		B) "_MI_R2"
		mi impute chained (pmm) Fhrshw Fhrsrep  Mhrshw Mhrsrep  ///	
						Mhlthsat Fhlthsat Mlifesat Flifesat yard ///
						Meffworkhrs ///
						Feffworkhrs ///
				  (pmm if syear > 1990) Fhrserr Mhrserr ///
				  = i.R2 i.kind16 c.hqm i.syear i.Mcurempl i.Fcurempl ///
					c.Minc c.Finc i.coupleidnum , rseed(123) replace report 
		C) "_MI_index"
		mi impute chained (pmm) Fhrshw Fhrsrep  Mhrshw Mhrsrep  ///	
						Mhlthsat Fhlthsat Mlifesat Flifesat yard ///
						Meffworkhrs ///
						Feffworkhrs ///
				  (pmm if syear > 1990) Fhrserr Mhrserr ///
				  = i.index2 i.kind16 c.hqm i.syear i.Mcurempl i.Fcurempl ///
					c.Minc c.Finc i.coupleidnum , rseed(123) replace report 
					
		A and B include transition period dummies R and R2 (refined).
		Instead, C used the exact year before/after the transition (variable index) and, thus, 
		is most precise, but also most demanding in terms of computing time.
		In general, it turned out that the results are very robust against several specifications. 
		For the final analysis we used the "_MI_index" model (C). 
 
  Input:  temp/01_sample.dta
  Output: temp/analysis_MI_R.dta
		  temp/analysis_MI_R2.dta	  
		  temp/analysis_MI_index.dta (the final analytical dataset)
 
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/



// configuration file
if "${config}"!="1" do config 

// use 01_sample, clear
use "${tempDir}/01_sample", clear

* Number of unique values of coupleid is  1302
* Number of records is  18484
unique coupleid  

*******************************************************
*
* A) Multiple Imputation 
* (turned off by default)
*
*******************************************************

if ${runimputation} == 1 {

********************************************
* Preparatory steps
********************************************

* Top-coding of implausible values in weekday hours for errands, housework, and repair/gardening  
* Set outliers (greater or equal 12 hours) to missings (only few cases). 
* Values will be imputed later.  
foreach num of numlist 1/2 {
	capt drop gt12*
	gen gt12_err = hrserr`num' >= 12 & hrserr`num' < .
	gen gt12_hw = hrshw`num' >= 12 & hrshw`num' < . if sy1990==0
	replace gt12_hw = hrshw`num' >= 12 & hrshw`num' < . if sy1990==1
	gen gt12_rep = hrsrep`num' >= 12 & hrsrep`num' < .
	fre gt12*
	
	replace hrserr`num' = .z if gt12_err==1
	replace hrshw`num' = .z if gt12_hw==1
	replace hrsrep`num' = .z if gt12_rep==1
	capt drop gt12*
}
* generate a numeric couple id
preserve 
	keep coupleid 
	duplicates drop
	count
	gen coupleidnum = _n
	tempfile coupleidnum
	save `coupleidnum'
restore
merge n:1 coupleid using `coupleidnum', assert(match) nogen
order coupleidnum, after(coupleid)


* generate variables for wife and husband
foreach var in pid gebjahr pgcasmin pglabnet pgemplst pgtatzt ///
			   hrsjobed hrserr hrshobb hrslearn hrshw hrscc hrsrep ///
			   TZ AL ///
{
	gen M`var' = `var'1 if sex1==1
	replace M`var' = `var'2 if sex2==1
	gen F`var' = `var'1 if sex1==2
	replace F`var' = `var'2 if sex2==2
	
}
* generate a more fine-grained transition variable
recode index (min/-5 = 0 "min/-5") ///
			 (-4 = 1 "-4") ///
			 (-3 = 2 "-3") ///
			 (-2 = 3 "-2") ///
			 (-1 = 4 "-1") ///
			 (0 = 5 "0") ///
			 (1 = 6 "1") ///
			 (2 = 7 "2") ///
			 (3 = 8 "3") ///
			 (4 = 9 "4") ///
			 (5/max = 10 "5/max") ///
			 , gen(R2)
* index2 
gen index2 = index+10
			 
* couple variables
d yard hqm kind16 MRE FRE R psample1 iyear1  

**********************************
* Analyse missing patterns
**********************************
* wife's variables
d Fhrshw Fhrsrep Fhrserr Fhrshobb Fhrsjobed Fhrscc Fhlthsat Fhlthself Fcurempl
misstable summarize Fhrshw Fhrsrep Fhrserr Fhrshobb Fhrsjobed Fhrscc Fhlthsat Fhlthself Fcurempl

* dependent variables (wife)
misstable patterns Fhrshw Fhrsrep Fhrserr	// 77% completeness in dependent variables
mvpatterns Fhrshw Fhrsrep Fhrserr, sort

* husband's variables
misstable summarize Mhrshw Mhrsrep Mhrserr Mhrshobb Mhrsjobed Mhrscc Mhlthsat Mhlthself Mcurempl

* dependent variables (husband)
misstable patterns Mhrshw Mhrsrep Mhrserr // 76% completeness

* independent variables 
misstable summarize R kind16 hqm Mhlthsat Fhlthsat Fcurempl
misstable patterns R kind16 hqm Mhlthsat Fhlthsat Fcurempl	// almost 75% completeness

* additional predictors for imputation
misstable summarize Mlifesat Flifesat

* generate dummies for income does not apply
gen M_incna = Mpglabnet == .b
gen F_incna = Fpglabnet == .b
recode Fpglabnet (.b = 0), gen(Finc) 
recode Mpglabnet (.b = 0), gen(Minc)

* other household variables as predictors
* hgroom: number of rooms over 6 m2 
* hgtyp1hh: household typology (1 digit)
* hgtyp2hh: household typology (2 digit)
* hgihinc: imputed household net income (mean over imputations)
* hgnuts1: NUTS level 1 (Bundesland)

gen M_effworkhrsna = Mpgtatzt == .b
recode Mpgtatzt (.b = 0), gen(Meffworkhrs)

gen F_effworkhrsna = Fpgtatzt == .b
recode Fpgtatzt (.b = 0), gen(Feffworkhrs)

* household income
gen hg_incna = hgihinc == .b
recode hgihinc (.b = 0), gen(Hinc)

misstable summarize yard Fhisced Mhisced Fhrshobb Fhrsjobed Fhrslearn Fhrscc Mhrshobb ///
					Mhrsjobed Mhrscc Mhrslearn Mgebjahr Fgebjahr M_incna Minc F_incna Finc ///
					hgroom hgtyp1hh hgtyp2hh hgnuts1 Hinc hg_incna Meffworkhrs M_effworkhrsna Feffworkhrs F_effworkhrsna ///
					psample1 iyear1  


* only keep relevant variables
keep 				syear hid sy1990 coupleidnum Fpid Mpid /// identifiers
					Fhrshw Fhrsrep Fhrserr Mhrshw Mhrsrep Mhrserr /// dependent variables
					R R2 index index2 kind16 hqm Mhlthsat Fhlthsat Mlifesat Flifesat Fcurempl /// independent variables
					yard Fhisced Mhisced Fhrshobb Fhrsjobed Fhrslearn Fhrscc Mhrshobb /// additional predictors
					Mhrsjobed Mhrscc Mhrslearn Mgebjahr Fgebjahr M_incna Minc F_incna Finc ///
					hgroom hgtyp1hh hgnuts1 Hinc hg_incna Meffworkhrs M_effworkhrsna Feffworkhrs F_effworkhrsna ///
					psample1 iyear1 Mcurempl

					
misstable summarize *


* set soft missings "." instead of hard missings (.a, .b, .c) since mi does not impute the latter
foreach var of varlist * {
	replace `var' = . if mi(`var')
}

* manually impute one missing value for Fcurempl 
* (avoid computationally intense imputation for only 1 missing value)
li hid F* syear if Fcurempl == . // inspect case: born 1930, 66 years old 
replace Fcurempl = 3 if hid==24791 & syear == 1996 // set to 3=marginal/not employed

misstable summarize *


**********************************
*
* Formulating the multiple imputation model
*
* Strategy
* - couple based imputation
* - chained equations
* - predictive mean matching for imputing hours 
*   (assures that only observed values are imputed, e.g. not negative hours)
* - couple fixed effects 
*   (that is consistent to the fixed effects approach in the analytical model)
* - generate M=5 imputations
**********************************

capt mi unset
mi set wide
mi set M = 5

* dependent variables with missing values
mi register imputed Fhrshw Fhrsrep Fhrserr Mhrshw Mhrsrep Mhrserr 
* independent variables with missing values
mi register imputed Mhlthsat Fhlthsat 
* additional predictors with missing values
mi register imputed yard Meffworkhrs Feffworkhrs Mlifesat Flifesat 



* attention: set errands to zero 1990 or before (hours for errands were asked jointly with housework in one item)
replace Mhrserr = 0 if sy1990==1
replace Fhrserr = 0 if sy1990==1

set matsize 8000

* those are almost perfectly associated
tab M_effworkhrsna M_incna
tab F_effworkhrsna F_incna
// note: already captured by F/Mcurempl; hence leave it out to simplify the model

log using "mi_log_MI_R", smcl replace
log on
 
* fixed couple effects specification (cluster indicators) of the chained equation model (dryrun)
* dry-run 
mi impute chained (pmm) Fhrshw Fhrsrep  Mhrshw Mhrsrep  ///	
						Mhlthsat Fhlthsat Mlifesat Flifesat yard ///
						Meffworkhrs ///
						Feffworkhrs ///
				  (pmm if syear > 1990) Fhrserr Mhrserr ///
				  = i.R i.kind16 c.hqm i.syear i.Mcurempl i.Fcurempl ///
					c.Minc c.Finc i.coupleidnum , rseed(123) replace report dryrun

* run the model (caution: can take hours even on a multi-core PC)
mi impute chained (pmm) Fhrshw Fhrsrep  Mhrshw Mhrsrep  ///	
						Mhlthsat Fhlthsat Mlifesat Flifesat  yard ///
						Meffworkhrs ///
						Feffworkhrs ///
				  (pmm if syear > 1990) Fhrserr Mhrserr ///
				  = i.R i.kind16 c.hqm i.syear i.Mcurempl i.Fcurempl ///
					c.Minc c.Finc i.coupleidnum , rseed(123) replace report 


* save imputed values and dataset
save "${tempDir}/02_imputation_MI_R", replace
log off
log close 


* alternative model using R2
log using "mi_log_MI_R2", smcl replace
log on



* run the model (caution: can take hours even on a multi-core PC)
mi impute chained (pmm) Fhrshw Fhrsrep  Mhrshw Mhrsrep  ///	
						Mhlthsat Fhlthsat Mlifesat Flifesat yard ///
						Meffworkhrs ///
						Feffworkhrs ///
				  (pmm if syear > 1990) Fhrserr Mhrserr ///
				  = i.R2 i.kind16 c.hqm i.syear i.Mcurempl i.Fcurempl ///
					c.Minc c.Finc i.coupleidnum , rseed(123) replace report 

* save imputed values and dataset
save "${tempDir}/02_imputation_MI_R2", replace

log off
log close 

* alternative model using index2
log using "mi_log_MI_index", smcl replace
log on



* run the model (caution: can take hours even on a multi-core PC)
mi impute chained (pmm) Fhrshw Fhrsrep  Mhrshw Mhrsrep  ///	
						Mhlthsat Fhlthsat Mlifesat Flifesat yard ///
						Meffworkhrs ///
						Feffworkhrs ///
				  (pmm if syear > 1990) Fhrserr Mhrserr ///
				  = i.index2 i.kind16 c.hqm i.syear i.Mcurempl i.Fcurempl ///
					c.Minc c.Finc i.coupleidnum , rseed(123) replace report 

* save imputed values and dataset
save "${tempDir}/02_imputation_MI_index", replace

log off
log close 

}	

*******************************************************
*
* B) Creating relevant variables based on the imputations
*
*******************************************************

* use dataset containing imputations
foreach mimodel in _MI_R _MI_R2 _MI_index {

use "${tempDir}/02_imputation`mimodel'", clear

* merge additional variables from original dataset (here only variable "index")
merge 1:1 hid syear using "${tempDir}/01_sample", keepusing(index) assert(matched) nogen

* describe multiple imputation dataset
mi query		// number of imputations (=5)
mi des, detail	// ~17.4% incomplete observations  
mi misstable summarize	// overview to missingness

*******
* compare means and SEs for full data (including imputations) vs. complete cases only
*******
// Note: "mi estimate" runs estimation commands on imputed data and adjusts
// 		 coefficients and standard errors for the variability between imputations 
//		 according to the combination rules by Rubin (1987).
//		 Point estimate: 
//				p = m^-1 * sum(p_j)	[m=number of imputations; p_j point estimation in m=j]
//		 Within imputation variance: 
//				u = m^-1 * sum(u_j)	[u_j variance of p in m=j]
//		 Between imputation variance: 
//				b = (m-1)^-1 * sum([p_j-p]^2)
//		 Total variance is
//				t = u + (1 + m^-1)*b
//		 overall standard error is
//				se = sqrt(t)
//
//		 Relative increase in variance due to non-response (RVI)
//				r = (1 + m^-1)* b/u
		 
* wife's houshold labor hours and health satisfaction
mi estimate: mean Fhrshw Fhrserr Fhrsrep Fhlthsat
mi estimate, vartable nocitable dftable

// Note: RVI (relative variance increase due to non-response) for mean estimation 
//		 is comparably low for all variables (<.1).
// 		 Highest for female repair hours (highest rate of missing values).
//		 Percentage of standard-error increase due to missing data is highest for repair hours (+4.37%)
//		 Reported relative efficiencies are high suggesting that 5 imputations are sufficient. 

* mean estimation based on complete cases only
mean Fhrshw Fhrserr Fhrsrep Fhlthsat // mi point estimates are usually somewhat larger (but only on the second digit).   

* husband
mi estimate: mean Mhrshw Mhrserr Mhrsrep Mhlthsat
mi estimate, vartable nocitable dftable
mean Mhrshw Mhrserr Mhrsrep Mhlthsat	// mi estimate is higher (.3 hours) for repairs



* create passive variables (having values that are functions of imputed variables)
mi passive: gen Fdwhrs = (Fhrserr+Fhrsrep+Fhrshw)*(sy1990==0) + (Fhrsrep+Fhrshw)*(sy1990==1)

* for complete cases only
replace Fdwhrs = Fhrserr+Fhrsrep+Fhrshw if sy1990==0
replace Fdwhrs = Fhrsrep+Fhrshw if sy1990==1

mi passive: gen Mdwhrs = (Mhrserr+Mhrsrep+Mhrshw)*(sy1990==0) + (Mhrsrep+Mhrshw)*(sy1990==1)

* for complete cases only
replace Mdwhrs = Mhrserr+Mhrsrep+Mhrshw if sy1990==0
replace Mdwhrs = Mhrsrep+Mhrshw if sy1990==1

mi estimate: mean Fdwhrs
mean Fdwhrs

mi estimate: mean Mdwhrs
mean Mdwhrs

***
* Calculation of shares
***
* 1) Total household labor
* couple hours: total household labor
mi passive: gen cpldwhrs = Fdwhrs + Mdwhrs

mi estimate: mean cpldwhrs
mean cpldwhrs

* husband's share: total household labor
mi passive: gen Mshrdw = 100*Mdwhrs/cpldwhrs

// note: sample size varies over imputations since in some impuations couple hours amount to zero .
//		Varying sample sizes can lead to bias and inefficiency if variation is substantial. 
//		However, here sample sizes vary only between 18473 and 18474.

mi estimate, esampvaryok: mean Mshrdw
mean Mshrdw

* 2) Housework
* couple hours
mi passive: gen cplhrshw = Fhrshw + Mhrshw

mi estimate: mean cplhrshw
mean cplhrshw

* husband's share
mi passive: gen Mshrhw = 100*Mhrshw/cplhrshw

// note: sample size varies over imputations since in some impuations couple hours amount to zero .
//		Varying sample sizes can lead to bias and inefficiency if variation is substantial. 
//		Here, sample size do not vary, but observations vary (but only 39 cases). 
mi estimate, esampvaryok: mean Mshrhw	
mean Mshrhw

* 3) Errands
* couple hours
mi passive: gen cplhrserr = Fhrserr + Mhrserr

mi estimate: mean cplhrserr
mean cplhrserr

* husband's share
mi passive: gen Mshrerr = 100*Mhrserr/cplhrserr

// note: sample size varies over imputations since in some impuations couple hours amount to zero .
//		Varying sample sizes can lead to bias and inefficiency if variation is substantial. 
//		However, here sample sizes vary only between 14904 and 14910.
mi estimate, esampvaryok: mean Mshrerr	
mean Mshrerr

* 4) Repairs
* couple hours
mi passive: gen cplhrsrep = Fhrsrep + Mhrsrep

mi estimate: mean cplhrsrep
mean cplhrsrep

* husband's share
mi passive: gen Mshrrep = 100*Mhrsrep/cplhrsrep

// note: sample size varies over imputations since in some impuations couple hours amount to zero .
//		Varying sample sizes can lead to bias and inefficiency if variation is substantial. 
//		However, here sample sizes vary only between 15353 and 15366
mi estimate, esampvaryok: mean Mshrrep	
mean Mshrrep


******
* independent variables
******

center hqm, pref(c)
* recale "living space" to 50m2 units
gen chqm50 = chqm/50

mi register regular chqm50 kind16

* standardize following imputed variables 
// Note: results in so called "super-varying" variables (in contrast to passive variables), 
//		 i.e. values will be different across imputations 
//		 even for complete cases. 
// Important: those variables must not be registered 
//		 (yet they can still be used in estimation commands). 
* before we can define super varying variables we have to convert the data to "flong" format
mi convert flong, clear
mi xeq: egen zMhlthsat = std(Mhlthsat) 
mi xeq: egen zFhlthsat = std(Fhlthsat)


********
* other variables
********
gen Fage = syear - Fgebjahr 
gen Mage = syear - Mgebjahr
 

**************
* store data being ready for analysis
**************
save "${tempDir}/analysis`mimodel'", replace
}
