/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, Thomas and Skopek, Jan (2015). Convergence or Continuity? 
  The Gender Gap in Household Labor After Retirement. In: Journal of 
  Marriage and Family.

  10_descriptives.do
  
  Descriptive analyses. Tables 1, 2, and 3. 
	
	- Table 1 - Number of Observations per Couple
	- Table 2 - Description and Coding of Analytical Variables
    - Table 3 - Descriptive Statistics on Sample of Couples Across Phase of 
				Retirement and First Observation
				
	Additional table: 
	- Table 3 (B) - Descriptive Statistics on Sample of Couples Across Survey 
					Years (not shown in the paper!)
				
   Input: 	temp/analysis{mi_model}.dta
   Output: 	log-files/Table_1_{mi_model}.smcl
			log-files/Table_2_{mi_model}.smcl
			log-files/Table_3_{mi_model}.smcl
			log-files/Table_3B_{mi_model}.smcl
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// configuration file
if "${config}"!="1" do config 

/*-----------------------------------------
  Load multiply imputed data
-----------------------------------------*/

// select imputation model (note: virtually the same results for different models)
glo mimodel = "_MI_index"

// load imputed data
use "${tempDir}/analysis${mimodel}", clear

// Note: the following lines only serve to illustrate the complex data structure 
//		 of the mi flong data format (one line per imputation m=1,...,5, and an 
//		 additional line for raw data m=0). 		 

* check multiple imputation data format
mi des	// 18.484 cases in total

* 110.904 
count // simple count ignoring mi data format

// Note: imputed data sets are identified by _mi_m > 0

* inspect flong format
sort coupleidnum syear _mi_m
li coupleidnum syear Fhrshw _* if coupleidnum==554 & syear==1985, sepby(coupleidnum syear)

* original dataset is _mi_m==0
count if _mi_m==0	// 18.484

* Example: frequencies of Fhrshw
fre Fhrshw if _mi_m==0	// 317 missings (raw data)
fre Fhrshw if _mi_m==1	// (imputation 1)
fre Fhrshw if _mi_m==2	// (imputation 1)

* add time varying variables for education
merge n:1 hid syear using "${tempDir}/01_sample", keepusing(sex1 sex2 pgisced2 pgcasmin2 pgisced1 pgcasmin1) nogen assert(matched)

gen Misced = pgisced1 if sex1==1
replace Misced = pgisced2 if sex2==1
gen Fisced = pgisced1 if sex1==2
replace Fisced = pgisced2 if sex2==2
gen Mcasmin = pgcasmin1 if sex1==1
replace Mcasmin = pgcasmin2 if sex2==1
gen Fcasmin = pgcasmin1 if sex1==2
replace Fcasmin = pgcasmin2 if sex2==2
lab val Mcasmin Fcasmin pgcasmin
lab val Misced Fisced pgisced
drop pgcasmin* pgisced*
drop sex?


/*-----------------------------------------
  Basic descriptives 
-----------------------------------------*/

* age range for men and women
by coupleidnum (_mi_m syear), sort: gen first = _n==1

* age range at first obs
sum Mage Fage if first==1 

* age range at retirement 
sum Mage Fage if index==0 & _mi_m==0

drop first


/*-----------------------------------------
  Table 1 - 
  Number of Observations per Couple
-----------------------------------------*/

// Note: do create that simple table we discard all imputations records (and extract the raw data).
preserve 
	* extract the raw data set from imputations
	mi extract 0, clear

	count 	// 18.484
		
	* Distribution of waves across couples
	bys coupleidnum (syear): gen first = _n==1
	bys coupleidnum (syear): gen waves = _N

	* table 1: 
	log using "${logDir}/Table_1_${mimodel}.smcl", smcl replace
	tab waves if first==1
	log close
restore 


/*-----------------------------------------
  Table 2 - 
  Description and Coding of Analytical Variables
-----------------------------------------*/
// Note: for that table we use the imputed data 
//		 (for variables with values varying across imputations [=variables with imputed values] 
//		  we need command mi_meansd to calculate standard deviation properly)

* Table 2 (I): hours
* Cacluate mean and standard deviation as well as min and max values 
* for imputed data
// Note: make use of the program mi_meansd that calculates those quantities for 
//		 multiply imputed data

log using "${logDir}/Table_2_${mimodel}.smcl", smcl replace

mi_meansd Fhrshw Mhrshw Fhrserr Mhrserr Fhrsrep Mhrsrep Fdwhrs Mdwhrs, f(%9.3g)
* missingness
mi misstable summarize Fhrshw Mhrshw Fhrserr Mhrserr Fhrsrep Mhrsrep Fdwhrs Mdwhrs

misstable summarize Fhrshw Mhrshw Fhrserr Mhrserr Fhrsrep Mhrsrep Fdwhrs Mdwhrs if _mi_m==0, gen(MISS)

tabstat MISS* if _mi_m==0, stats(mean N) f(%9.4f) col(stats)
drop MISS*

// Table 2 (II): Health satisfaction
mi_meansd Fhlthsat Mhlthsat, f(%9.3g)
misstable summarize Fhlthsat Mhlthsat if _mi_m==0, gen(MISS)
tabstat MISS* if _mi_m==0, stats(mean N) f(%9.4f) col(stats)
drop MISS*

// Table 2 (III): Wife's employment state (working hours)
// recode to daily hours
mi xeq: replace Feffworkhrs = Feffworkhrs/5
mi update

mi_meansd Feffworkhrs, f(%9.3g)
misstable summarize Feffworkhrs if _mi_m==0, gen(MISS)
tabstat MISS* if _mi_m==0, stats(mean N) f(%9.4f) col(stats)
drop MISS*

// Table 2 (IV): household
mi_meansd hqm yard kind16, f(%9.3g)
misstable summarize hqm yard kind16 if _mi_m==0, gen(MISS)
tabstat MISS* if _mi_m==0, stats(mean N) f(%9.4f) col(stats)
drop MISS*

log close

/*-----------------------------------------
  Table 3 (B) - 
  Descriptive Statistics on Sample of Couples 
  Across Survey Years
  (not shown in the paper!)
-----------------------------------------*/

// Note: calculating the table is complex in context of multiply imputed data.
//		 Hence, we build first the parts and fuse everything together at the end.		
tab Fcurempl, gen(Fempl)
rename Fempl1 F_FT
rename Fempl2 F_PT
mi register regular F_FT F_PT

capt mat drop R
capt mat drop obs 
capt mat drop E 
capt mat drop e
capt mat drop r
local years ""
foreach year of numlist 1985/2012 {
	mi estimate, post: mean Mage Mhlthsat Mdwhrs Fage Fhlthsat F_FT F_PT Fdwhrs kind16 hqm if syear==`year'
	mat r = e(b)
	mat li r
	mat R = nullmat(R) \ r
	mat drop r
	local years "`years' `year'"
}

* observations
tab syear if _mi_m==0, matcell(o)

* events
capt drop t
gen t = index==0
tab syear t if _mi_m==0, matcell(E)
matrix e = E[1..., "c2"] 

mat R = R , o, e 

* total row
mi estimate, post: mean Mage Mhlthsat Mdwhrs Fage Fhlthsat F_FT F_PT Fdwhrs kind16 hqm 
mat r = e(b)
count if _mi_m==0
local N = r(N)
count if index==0 & _mi_m==0
local e = r(N)
mat obs = (`N', `e')
mat r = r,obs

mat R = R \ r

local years "`years' total"

matname R `years', rows(.) explicit
matname R Mage Mhlthsat Mdwhrs Fage Fhlthsat F_FT F_PT Fdwhrs kind16 hqm obs e, col(.) explicit

drop F_FT F_PT t Fempl3

* print Table 3B
log using "${logDir}/Table_3B_${mimodel}.smcl", smcl replace
matlist R, cspec(& %16s & %9.0f & %9.1f & %9.1f & %9.0f & %9.1f & %9.2f & %9.2f & %9.1f & %9.2f & %9.0f & %9.0f & %9.0f &) ///
		   rspec(--&&&&& &&&&& &&&&& &&&&& &&&&& &&--)

log close


/*-----------------------------------------
  Table 3 - 
  Descriptive Statistics on Sample of Couples 
  Across Phase of Retirement and First Observation
-----------------------------------------*/

* gen a dummy for no income
mi xeq: gen Fnoinc = Finc == 0
mi xeq: gen Mnoinc = Minc == 0

* rescale female working ours (weekly) to daily by dividing by 5
mi xeq: replace Feffworkhrs = Feffworkhrs / 5 
mi xeq: replace Meffworkhrs = Meffworkhrs / 5 

mi update

tab Fcurempl, gen(Fempl)
rename Fempl1 F_FT
rename Fempl2 F_PT
mi register regular F_FT F_PT

gen Feduhigh = Fisced > 4 & !mi(Fisced)
gen Meduhigh = Misced > 4 & !mi(Misced)

capt mat drop R
capt mat drop obs 
capt mat drop E 
capt mat drop e
capt mat drop r
local phases ""


* fully imputed variables
local nonmissing Mage Mhlthsat Mdwhrs Meffworkhrs Mnoinc Fage ///
			     Fhlthsat F_FT F_PT Fdwhrs Feffworkhrs Fnoinc ///
				 kind16 hqm yard
mi misstable summarize `nonmissing', m(1) 

foreach i of numlist -10/10 {
	* only non missing variables here (i.e. variables with fully imputed values in m)
	* (otherwise mean will result in a list-wise deleted sample)
	mi estimate, post: mean `nonmissing' if index==`i'
	mat R = nullmat(R) \ e(b)
	
	local phases "`phases' `i'"
}

* add number of couples (first statistic in the table)
by index coupleidnum _mi_m, sort: gen first= _n==1

tab index first if _mi_m==0, matcell(C)
matrix c = C[1..., "c1"] 
mat R = c, R  

drop first

* Couples statistics at couple's first observation (last row in the table)
mi xeq: by coupleidnum (index), sort: gen first= _n==1
capt mat drop r
mi estimate, post: mean `nonmissing' if first==1
mat r = e(b)

count if first==1 & _mi_m==0
mat r = (`r(N)'), r

mat R = R \ r

// build parts of table 3
tempfile table3 table3_2
// first part
preserve 
	clear
	svmat R, names(col)
	rename c1 couples
	format ?age ?hlthsat ?dwhrs ?effworkhrs %9.1f
	format hqm %9.0f 
	format F_* kind16 ?noinc  %9.2f
	gen index = _n -11 if _n <_N
	order index, first
	save `table3', replace
restore

* the education variables have some few missing values 
capt mat drop M 
foreach i of numlist -10/10 {
	// capt drop first
	// mi xeq: by coupleidnum (index), sort: gen first= _n==1
	capt mat drop r
	foreach var of varlist Misced Fisced Meduhigh Feduhigh {
		mean `var' if _mi_m==0 & index==`i'
		mat r = nullmat(r), (_b[`var'])
	}
	mat M = nullmat(M) \ r
}
* Couples statistics at couple's first observation (last row in the table)
capt drop first
mi xeq: by coupleidnum (index), sort: gen first= _n==1
capt mat drop r
foreach var of varlist Misced Fisced Meduhigh Feduhigh {
		mean `var' if _mi_m==0 & first==1
		mat r = nullmat(r), (_b[`var'])
}
mat M = M \ r

* build second part of table 3
preserve 
	clear
	svmat M
	rename M1 Misced
	rename M2 Fisced
	rename M3 Meduhigh 
	rename M4 Feduhigh
	replace Meduhigh = Meduhigh*100
	replace Feduhigh = Feduhigh*100
	
	format ?isced ?eduhigh %9.1f
	gen index = _n -11 if _n <_N
	order index, first
	save `table3_2', replace
restore

// merge table parts
use `table3', clear
merge 1:1 index using `table3_2', assert(matched) nogen

order index couples M* F* kind16 hqm 
format F_* kind16 %9.4f

foreach var of varlist  kind16 yard {
	replace `var' = 100*`var'
	format `var' %9.1f
}
 
// print Table 3
log using "${logDir}/Table_3_${mimodel}.smcl", smcl replace
li index couples Mage Mhlthsat Mdwhrs Meffworkhrs Meduhigh ///
			     Fage Fhlthsat Fdwhrs Feffworkhrs Feduhigh ///
				 kind16 hqm yard, clean noobs
log close




