/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, Thomas and Skopek, Jan (2015). Convergence or Continuity? 
  The Gender Gap in Household Labor After Retirement. In: Journal of 
  Marriage and Family.

  11_fixed_effects_models.do
  
  Estimates fixed effects models on shares and hours. 
  Generates Table A1 and Figure 1 and 2 (subplots). 
  
  Table A1 - Fixed Effects Regression Models 
			 for Change in 12 Outcomes After 
			 Husband's Retirement.
			 
  Figure 1 - Changes in Total Household Labor 
			 Across the Husband's Transition 
			 to Retirement.
			 
  Figure 2 - Changes in Routine Housework, 
			 Errands, and Repairs/Gardening 
			 Across Husbands's Transitions to
			 Retirement.
			 
  Input: 	temp/analysis{mi_model}.dta
  Output: 	log-files/Table_1_{mi_model}.smcl
			log-files/Table_2_{mi_model}.smcl
			log-files/Table_3_{mi_model}.smcl
			log-files/Table_3B_{mi_model}.smcl
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// configuration file
if "${config}"!="1" do config 


log using "${logDir}/FE_models.smcl", smcl replace
log on

/*-----------------------------------------
  Load multiply imputed data and xtset 
  longitudinal data
-----------------------------------------*/

// select imputation model (note: virtually the same results for different models)
glo mimodel = "_MI_index"

// load imputed data
use "${tempDir}/analysis${mimodel}", clear


* mi data
mi query

* define clusters for fixed effects models
mi xtset coupleidnum

* standardize following imputed variables 
// Note: results in so called "super-varying" variables (in contrast to passive variables), 
//		 i.e. values will be different across imputations 
//		 even for complete cases. 
// Important: those variables must not be registered 
//		 (yet they can still be used in estimation commands). 
* before we can define super varying variables we have to convert the data to "flong" format
* data is already in flong format
mi xeq: egen zMlifesat = std(Mlifesat) 
mi xeq: egen zFlifesat = std(Flifesat)

* yard available (center to represent the average)
mi xeq: egen myard = mean(yard)
mi xeq: gen cyard = yard - myard
drop myard

* rescale female working ours (weekly) to daily by dividing by 5
mi xeq: replace Feffworkhrs = Feffworkhrs / 5 
mi update



/*-----------------------------------------
  Run fixed effects models
-----------------------------------------*/

* set ID
mi xtset coupleidnum

* Model specification (it's called "model2" to distinguish from an earlier model, 
* not reported)
glo model2 ib0.R2 kind16 c.chqm50 c.zMhlthsat c.zFhlthsat c.Feffworkhrs c.cyard


/*-----------------------------------------
  I) Household labor (total)
-----------------------------------------*/
* Husband's share
mi estimate, post: xtreg Mshrdw $model2, fe
est store sharehhl2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats sharehhl2

* Hours of wife
mi estimate, post: xtreg Fdwhrs $model2, fe
est store Fdwhrs2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats Fdwhrs2

* Hours of husband
mi estimate, post: xtreg Mdwhrs $model2, fe
est store Mdwhrs2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats Mdwhrs2
				  
				  
/*-----------------------------------------
  II) Housework
 
  Note: restricted to 1991+ (since up 1990 
		asked together with errands)
 
-----------------------------------------*/

* Husband's share
mi estimate,   esampvaryok post: xtreg Mshrhw $model2 if sy1990==0, fe
est store sharehw2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...
_mi_addstats sharehw2

* Hours of wife
mi estimate, post: xtreg Fhrshw $model2 if sy1990==0, fe
est store Fhrshw2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats Fhrshw2

* Hours of husband
mi estimate, post: xtreg Mhrshw $model2 if sy1990==0, fe
est store Mhrshw2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats Mhrshw2				  


/*-----------------------------------------
  III) Errands
 
  Note: restricted to 1991+ (since up 1990 
		asked together with housework)
 
-----------------------------------------*/	  

* Husband's share
mi estimate,   esampvaryok post: xtreg Mshrerr $model2 if sy1990==0, fe
est store shareerr2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...
_mi_addstats shareerr2

* Hours of wife
mi estimate, post: xtreg Fhrserr $model2 if sy1990==0, fe
est store Fhrserr2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats Fhrserr2

* Hours of husband
mi estimate, post: xtreg Mhrserr $model2 if sy1990==0, fe
est store Mhrserr2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats Mhrserr2				  


/*-----------------------------------------
  IV) Repairs
-----------------------------------------*/

* Husband's share
mi estimate,   esampvaryok post: xtreg Mshrrep $model2 , fe
est store sharerep2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...
_mi_addstats sharerep2

* Hours of wife
mi estimate, post: xtreg Fhrsrep $model2 , fe
est store Fhrsrep2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats Fhrsrep2

* Hours of husband
mi estimate, post: xtreg Mhrsrep $model2 , fe
est store Mhrsrep2
* mi statistics
mi estimate, dftable vartable
* add model statistics (r2, rho, ...)
_mi_addstats Mhrsrep2				  

log close

* Save all model estimates

foreach name in          sharehhl2 sharehw2 shareerr2 sharerep2 ///
						 Mdwhrs2 Mhrshw2 Mhrserr2 Mhrsrep2 ///
						 Fdwhrs2 Fhrshw2 Fhrserr2 Fhrsrep2   {
						 
	est restore `name'
	est save "${logDir}/`name'", replace	
}


/*-----------------------------------------
  Combine results 

  Table A1 - Fixed Effects Regression Models 
			 for Change in 12 Outcomes After 
			 Husband's Retirement
			 
-----------------------------------------*/

foreach name in          sharehhl2 sharehw2 shareerr2 sharerep2 ///
						 Mdwhrs2 Mhrshw2 Mhrserr2 Mhrsrep2 ///
						 Fdwhrs2 Fhrshw2 Fhrserr2 Fhrsrep2   {
						 
	est use "${logDir}/`name'"
	est store `name'
	est restore `name'
}

estout sharehhl2 sharehw2 shareerr2 sharerep2 ///
			    Mdwhrs2 Mhrshw2 Mhrserr2 Mhrsrep2 ///
				Fdwhrs2 Fhrshw2 Fhrserr2 Fhrsrep2 ///
				using "${logDir}/Table_A1.txt" ///
				, cells(b(fmt(%9.2f)) se(par star))  ///
				  stats(N N_g e_r2_w df_m e_rho rvi_avg_mi fmi_max_mi, fmt(%9.2g) labels("Observations" "Clusters (Couples)" "R-sqr. (within)" "Degrees of Freedom" "rho" "RVI (avg)" "FMI (max)")) /// 
				  nolz /// 
				  starlevels(* .05 ** .01 *** .001) ///
				  varlabels(_cons "Constant (grand mean)" ///
							kind16 "Child < 16 in HH" ///
							chqm50 "Living space (cent.)" ///
							cyard "yard (cent.)" ///
							1.Fcurempl "Wife full-time" ///
							2.Fcurempl "Wife part-time" ///
							zMhlthsat "H's satisf. health (z-stand.)" ///
							zFhlthsat "W's satisf. health (z-stand.)" ///
							zMhself "H's self-r. health (z-stand.)" ///
							zFhself "H's self-r. health (z-stand.)" ///
							Feffworkhrs "W's effective working hours)" ///
							1.R2 "-4 years" ///
							2.R2 "-3 year" ///
							3.R2 "-2 year" ///
							4.R2 "-1 year" ///
							5.R2 "0 ret. within last year" ///
							6.R2 "+1 year" ///
							7.R2 "+2 years" ///
							8.R2 "+3 years" ///
							9.R2 "+4 years" ///
							10.R2 "+5/10 years" ///
							) /// 
				  order(_cons 1.R2 2.R2 3.R2 4.R2 5.R2 6.R2 7.R2 8.R2 9.R2 10.R2  ///
							  kind16 chqm50 cyard Feffworkhrs zMhlthsat zFhlthsat) ///
				  drop( 0b.R2 ) ///
				  varwidth(25) ///
				  modelwidth(10) ///
				  legend ///
				  replace ///
				  style(tab) ///
				  title("fixed effects regression") ///
				  mgroup(THL HW ERR REP MTHL MHW MERR MREP FTHL FHW FERR FREP)

preserve 				  
* varying case numbers for sharehw2 shareerr2 sharerep2
est restore sharehw2 
_mi_cases

est restore shareerr2 
_mi_cases

est restore sharerep2
_mi_cases
restore				  
				  
/*-----------------------------------------
  Draw plots 

  Figure 1 - Changes in Total Household Labor 
			 Across the Husband's Transition 
			 to Retirement.
  Figure 2 - Changes in Routine Housework, 
			 Errands, and Repairs/Gardening 
			 Across Husband's Transitions to
			 Retirement.
			 (-> subplots are generated)
-----------------------------------------*/

* axis for husbands
sum Mage if R2==5
local age0 = round(`r(mean)')
local agem10 = `age0'-10
local agem5 = `age0'-5
local agem4 = `age0'-4
local agem3 = `age0'-3
local agem2 = `age0'-2
local agem1 = `age0'-1
local agep1 = `age0'+1
local agep2 = `age0'+2
local agep3 = `age0'+3
local agep4 = `age0'+4
local agep5 = `age0'+5
local agep10 = `age0'+10

di `age0'-1 

global Mindexlab 0 "`agem10' to `agem5'" 1 "`agem4'" 2 "`agem3'" 3 "`agem2'" ///
				4 "`agem1'" 5 "`age0'" 6 "`agep1'" 7 "`agep2'" ///
				8 "`agep3'" 9 "`agep4'" 10 "`agep5' to `agep10'"

* xaxis for husbands
sum Fage if R2==5
local age0 = round(`r(mean)')
local agem10 = `age0'-10
local agem5 = `age0'-5
local agem4 = `age0'-4
local agem3 = `age0'-3
local agem2 = `age0'-2
local agem1 = `age0'-1
local agep1 = `age0'+1
local agep2 = `age0'+2
local agep3 = `age0'+3
local agep4 = `age0'+4
local agep5 = `age0'+5
local agep10 = `age0'+10


global Findexlab 0 "`agem10' to `agem5'" 1 "`agem4'" 2 "`agem3'" 3 "`agem2'" ///
				4 "`agem1'" 5 "`age0'" 6 "`agep1'" 7 "`agep2'" ///
				8 "`agep3'" 9 "`agep4'" 10 "`agep5' to `agep10'"
				

				
* set ID
mi xtset coupleidnum

* calculate shares
shrmargins, model(Mshrdw)
mat SHR = r(shr)
mat SHR = SHR'
* calculate hours
hrsmargins, model(dwhrs)	
mat HRS = r(C)
mat HRSF = HRS[4..6,1..11]'
mat HRSM = HRS[1..3,1..11]'		 

/*-----------------------------------------
  Figure 1 - Changes in Total Household Labor 
			 Across the Husband's Transition 
			 to Retirement.
-----------------------------------------*/

* combine 
set scheme lean1
preserve 
	foreach item in SHR HRSF HRSM {
		clear 
		svmat `item', names(col)
		gen type = "`item'"
		gen index = _n-1
		tempfile `item'
		save ``item''
	}
	use `SHR', clear
	append using `HRSF'
	append using `HRSM'
	
	// lab def index 0 "-10/-3" 1 "-2" 2 "-1" 3 "0" 4 "+1" 5 "+2" 6 "+3/+10", modify
	// lab def ${Mindexlab}
	// lab val index index
	li
	gen string = string(b, "%9.0f") + "%" if type == "SHR"
	replace string = string(b, "%9.1f")  if type!="SHR"
	twoway (rspike ll ul index if type=="HRSM", lcolor(gs0) lwidth(medthick) xaxis(1)) ///
		   (scatter b index if type=="HRSM", connect(l) msymb(O) mfcolor(black) mlabel(string) mlabcol(gs8) mlabpos(6) ///
					mlabgap(*2) mlabsize(*.7) mlwidth(vthin) clpattern(solid) clwidth(medium) lcolor(gs0) xaxis(1) yaxis(1)) ///
		   (rspike ll ul index if type=="HRSF", lcolor(gs0) lwidth(medthick) xaxis(2) yaxis(1)) ///
		   (scatter b index if type=="HRSF", connect(l) msymb(O) mfcolor(white) mlabel(string) mlabcol(gs8) mlabpos(12) ///
					mlabgap(*2) mlabsize(*.7) mlwidth(medium) clpattern(solid) clwidth(medium) clcolor(gs10) xaxis(2) yaxis(1)) ///
		   (rspike ll ul index if type=="SHR", lcolor(gs10) lwidth(medthick) xaxis(1) yaxis(2)) ///
		   (scatter b index if type=="SHR", sort connect(l) mlabel(string) mlabpos(12) mlabcol(gs8) /// 
					mlabsize(*.7) mlabgap(*1.7) msym(none) lcolor(gs8) lwidth(thin) lpat(dash) xaxis(1) yaxis(2)) ///
		   , ylabel(5 "5%" 15 "15%" 25 "25%" 35 "35%" 45 "45%" 55 "55%", axis(2) labsize(small)) /// ylabel(10 "10%" 20 "20%" 30 "30%" 40 "40%" 50 "50%" 60 "60%", axis(2) labsize(small))  ///
		   ylabel(2 "2h" 3 "3h" 4 "4h" 5 "5h" 6 "6h" 7 "7h" , axis(1) labsize(small)) ///
		   ymtick(1.5(.5)7, axis(1)) ymtick(10(5)60, axis(2))  /// xlabel(0 "-10/-5" 1 "-5/-4" 2 "-4/-3" 3 "-3/-2" 4 "-2/-1" 5 "-1/0" 6 "1/2" 7 "2/3" 8 "3/4" 9 "4/5" 10 "5/10", angle(45) labsize(small) axis(2) ) xlabel(${Mindexlab}, labsize(small) axis(1))  /// 
		   xlabel(0 "-10 to -5" 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3" 9 "4" 10 "5 to 10", labsize(small) axis(2)) xlabel(${Mindexlab}, labsize(small) axis(1)) ///
		   xline(5, lcolor(gs12) lwidth(vthin) lpat(dash) axis(1)) /// xtitle("Years before/after husband's retirement", axis(2) size(medsmall)) xtitle("Age of husband", axis(1) size(medsmall))   ///
		   xtitle("", axis(2) size(medsmall)) xtitle("", axis(1) size(medsmall)) ///
		   ytitle("", axis(1)) ytitle("", axis(2)) ///
		   legend(lab(6 "Husband's share") lab(2 "Husband's hours") lab(4 "Wife's hours") ///
					rows(3) order(4 2 6) ring(0) position(4) size(small)) ///
		   xsize(12) ysize(10) ///
		   scheme(lean1) graphregion(margin(zero)) ///
		   text(1.5 4.8 "retired", xaxis(1) yaxis(1) placement(north) orientation(vertical) size(vsmall) color(gs12)) 	///
		   saving("${logDir}/Graph_Household_Labor", replace) name("Graph_Household_Labor", replace)
graph export "${logDir}/Graph_Household_Labor.pdf", name("Graph_Household_Labor") replace
// only for windows
capt graph export "${logDir}/Graph_Household_Labor.emf", name("Graph_Household_Labor") replace

restore

/*-----------------------------------------
  Figure 2 - Changes in Routine Housework, 
			 Errands, and Repairs/Gardening 
			 Across Husbands's Transitions to
			 Retirement.
			 
  Subplots are generated. 
-----------------------------------------*/

/*-----------------------------------------
  (1) Housework 
  (restricted to 1991+!)
-----------------------------------------*/
* calculate shares
shrmargins if sy1990==0, model(Mshrhw)
mat SHR = r(shr)
mat SHR = SHR'
* calculate hours
hrsmargins if sy1990==0, model(hrshw)	
mat HRS = r(C)
mat HRSF = HRS[4..6,1..11]'
mat HRSM = HRS[1..3,1..11]'	

* combine 
set scheme lean1
preserve 
	foreach item in SHR HRSF HRSM {
		clear 
		svmat `item', names(col)
		gen type = "`item'"
		gen index = _n-1
		tempfile `item'
		save ``item''
	}
	use `SHR', clear
	append using `HRSF'
	append using `HRSM'
	
	// lab def index 0 "-10/-3" 1 "-2" 2 "-1" 3 "0" 4 "+1" 5 "+2" 6 "+3/+10", modify
	// lab def ${Mindexlab}
	// lab val index index
	li
	gen string = string(b, "%9.0f") + "%" if type == "SHR"
	replace string = string(b, "%9.1f")  if type!="SHR"
	twoway (rspike ll ul index if type=="HRSM", lcolor(gs0) lwidth(medthick) xaxis(1)) ///
		   (scatter b index if type=="HRSM", connect(l) msymb(O) mfcolor(black) mlabel(string) mlabcol(gs8) mlabpos(6) ///
					mlabgap(*2) mlabsize(*.7) mlwidth(vthin) clpattern(solid) clwidth(medium) lcolor(gs0) xaxis(1) yaxis(1)) ///
		   (rspike ll ul index if type=="HRSF", lcolor(gs0) lwidth(medthick) xaxis(2) yaxis(1)) ///
		   (scatter b index if type=="HRSF", connect(l) msymb(O) mfcolor(white) mlabel(string) mlabcol(gs8) mlabpos(12) ///
					mlabgap(*2) mlabsize(*.7) mlwidth(medium) clpattern(solid) clwidth(medium) clcolor(gs10) xaxis(2) yaxis(1)) ///
		   (rspike ll ul index if type=="SHR", lcolor(gs10) lwidth(medthick) xaxis(1) yaxis(2)) ///
		   (scatter b index if type=="SHR", sort connect(l) mlabel(string) mlabpos(12) mlabcol(gs8) /// 
					mlabsize(*.7) mlabgap(*3) msym(none) lcolor(gs8) lwidth(thin) lpat(dash) xaxis(1) yaxis(2)) ///
		   , ylabel(0 "0%" 10 "10%" 20 "20%" 30 "30%" 40 "40%", axis(2) labsize(small))  ///
		   ylabel(0 "0h" 1 "1h " 2 "2h" 3 "3h" 4 "4h" 5 "5h" , axis(1) labsize(small)) ///
		   ymtick(0(.5)5, axis(1)) ymtick(10(5)40, axis(2))  ///
		   xlabel(0 "-10 to -5" 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3" 9 "4" 10 "5 to 10", labsize(small) axis(2)) xlabel(${Mindexlab}, labsize(small) axis(1)) ///
		   xline(5, lcolor(gs12) lwidth(vthin) lpat(dash) axis(1)) ///
		   xtitle("", axis(2) size(medsmall)) xtitle("", axis(1) size(medsmall))  ytitle("", axis(1)) ytitle("", axis(2)) ///
		   legend(lab(6 "Husband's share") lab(2 "Husband's hours") lab(4 "Wife's hours") ///
					rows(3) order(4 2 6) ring(0) position(2) size(small) region(color(none))) ///
		   xsize(12) ysize(10) ///
		   scheme(lean1) graphregion(margin(zero)) ///
		   text(0 4.8 "retired", xaxis(1) yaxis(1) placement(north) orientation(vertical) size(vsmall) color(gs12)) ///
		   saving("${logDir}/Graph_Housework", replace) name("Graph_Housework", replace)
graph export "${logDir}/Graph_Housework.pdf", name("Graph_Housework") replace
// only for windows
capt graph export "${logDir}/Graph_Housework.emf", name("Graph_Housework") replace


restore

/*-----------------------------------------
 (2) Errands
 (restricted to 1991+!)
-----------------------------------------*/

* calculate shares
shrmargins if sy1990==0, model(Mshrerr)
mat SHR = r(shr)
mat SHR = SHR'
* calculate hours
hrsmargins if sy1990==0, model(hrserr)	
mat HRS = r(C)
mat HRSF = HRS[4..6,1..11]'
mat HRSM = HRS[1..3,1..11]'	

* combine 
set scheme lean1
preserve 
	foreach item in SHR HRSF HRSM {
		clear 
		svmat `item', names(col)
		gen type = "`item'"
		gen index = _n-1
		tempfile `item'
		save ``item''
	}
	use `SHR', clear
	append using `HRSF'
	append using `HRSM'
	
	// lab def index 0 "-10/-3" 1 "-2" 2 "-1" 3 "0" 4 "+1" 5 "+2" 6 "+3/+10", modify
	// lab def ${Mindexlab}
	// lab val index index
	li
	gen string = string(b, "%9.0f") + "%" if type == "SHR"
	replace string = string(b, "%9.1f")  if type!="SHR"
	twoway (rspike ll ul index if type=="HRSM", lcolor(gs0) lwidth(medthick) xaxis(1)) ///
		   (scatter b index if type=="HRSM", connect(l) msymb(O) mfcolor(black) mlabel(string) mlabcol(gs8) mlabpos(6) ///
					mlabgap(2.5) mlabsize(*.7) mlwidth(vthin) clpattern(solid) clwidth(medium) lcolor(gs0) xaxis(1) yaxis(1)) ///
		   (rspike ll ul index if type=="HRSF", lcolor(gs0) lwidth(medthick) xaxis(2) yaxis(1)) ///
		   (scatter b index if type=="HRSF", connect(l) msymb(O) mfcolor(white) mlabel(string) mlabcol(gs8) mlabpos(12) ///
					mlabgap(2.7) mlabsize(*.7) mlwidth(medium) clpattern(solid) clwidth(medium) clcolor(gs10) xaxis(2) yaxis(1)) ///
		   (rspike ll ul index if type=="SHR", lcolor(gs10) lwidth(medthick) xaxis(1) yaxis(2)) ///
		   (scatter b index if type=="SHR", sort connect(l) mlabel(string) mlabpos(12) mlabcol(gs8) /// 
					mlabsize(*.7) mlabgap(*2.5) msym(none) lcolor(gs8) lwidth(thin) lpat(dash) xaxis(1) yaxis(2)) ///
		   , ylabel(0 "0%" 10 "10%" 20 "20%" 30 "30%" 40 "40%" 50 "50%" 60 "60%" 70 "70%" 80 "80%" 90 "90%", axis(2) labsize(small))  ///
		   ylabel(0.5 "0.5h" 1 "1h " 1.5 "1.5h" 2 "2h" , axis(1) labsize(small)) ///
		   ymtick(.5(.5)2, axis(1)) ymtick(0(5)90, axis(2))  ///
		   xlabel(0 "-10 to -5" 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3" 9 "4" 10 "5 to 10", labsize(small) axis(2)) xlabel(${Mindexlab}, labsize(small) axis(1)) ///
		   xline(5, lcolor(gs12) lwidth(vthin) lpat(dash) axis(1)) ///
		   xtitle("", axis(2) size(medsmall)) xtitle("", axis(1) size(medsmall))  ytitle("", axis(1)) ytitle("", axis(2)) ///
		   legend(lab(6 "Husband's share") lab(2 "Husband's hours") lab(4 "Wife's hours") ///
					rows(3) order(4 2 6) ring(0) position(4) size(small) region(color(none))) ///
		   xsize(12) ysize(10) ///
		   scheme(lean1) graphregion(margin(zero)) ///
		   text(0.5 4.8 "retired", xaxis(1) yaxis(1) placement(north) orientation(vertical) size(vsmall) color(gs12))    ///
		   saving("${logDir}/Graph_Errands", replace) name("Graph_Errands", replace)
graph export "${logDir}/Graph_Errands.pdf", name("Graph_Errands") replace
// windows
capt graph export "${logDir}/Graph_Errands.emf", name("Graph_Errands") replace

restore

/*-----------------------------------------
  (3) Repairs
  (unrestricted)
-----------------------------------------*/

* calculate shares
shrmargins, model(Mshrrep)
mat SHR = r(shr)
mat SHR = SHR'
* calculate hours
hrsmargins, model(hrsrep)	
mat HRS = r(C)
mat HRSF = HRS[4..6,1..11]'
mat HRSM = HRS[1..3,1..11]'		
					
* combine 
set scheme lean1
preserve 
	foreach item in SHR HRSF HRSM {
		clear 
		svmat `item', names(col)
		gen type = "`item'"
		gen index = _n-1
		tempfile `item'
		save ``item''
	}
	use `SHR', clear
	append using `HRSF'
	append using `HRSM'
	
	// Note: adjust marker label positions
	* gen a marker position variable
	gen pos = 12 if type=="SHR"
	replace pos = 6 if type=="SHR" & index >= 4
	replace pos = 6 if type=="HRSF" 
	/*
	
		replace pos = 6 if type=="HRSF"
	replace pos = 8 if type=="HRSF" & index == 1
	replace pos = 2 if type=="HRSF" & index == 0
	*/
	li
	gen string = string(b, "%9.0f") + "%" if type == "SHR"
	replace string = string(b, "%9.1f")  if type!="SHR"
	twoway (scatter b index if type=="HRSF", msymbol(none) xaxis(1) yaxis(1)) /// pseudo scatter just for setting the axes correctly
		   (rspike ll ul index if type=="SHR", lcolor(gs10) lwidth(medthick) xaxis(2) yaxis(2)) ///
		   (scatter b index if type=="SHR", sort connect(l) mlabel(string) mlabv(pos) mlabcol(gs8) /// 
					mlabsize(*.7) mlabgap(2.5) msym(none) lcolor(gs8) lwidth(thin) lpat(dash) xaxis(2) yaxis(2)) ///
		   (rspike ll ul index if type=="HRSM", lcolor(gs0) lwidth(medthick) xaxis(1) yaxis(1)) ///
		   (scatter b index if type=="HRSM", connect(l) msymb(O) mfcolor(black) mlabel(string) mlabcol(gs8) mlabpos(12) ///
					mlabgap(3.3) mlabsize(*.7) mlwidth(vthin) clpattern(solid) clwidth(medium) lcolor(gs0) xaxis(1) yaxis(1)) ///
		   (rspike ll ul index if type=="HRSF", lcolor(gs0) lwidth(medthick) xaxis(1) yaxis(1)) ///
		   (scatter b index if type=="HRSF", connect(l) msymb(O) mfcolor(white) mlabel(string) mlabcol(gs8) mlabv(pos) ///
					mlabgap(1.5) mlabsize(*.7) mlwidth(medium) clpattern(solid) clwidth(medium) clcolor(gs10) xaxis(1) yaxis(1)) ///
			, ///
		   ylabel(0 "0%" 10 "10%" 20 "20%" 30 "30%" 40 "40%" 50 "50%" 60 "60%" 70 "70%" 80 "80%" 90 "90%", axis(2) labsize(small))  /// ylabel(40 "40%" 50 "50%" 60 "60%" 70 "70%" 80 "80%" 90 "90%", axis(2) labsize(small))  ///
		   ylabel(0.5 "0.5h" 1 "1h " 1.5 "1.5h" 2 "2h" , axis(1) labsize(small)) ///
		   ymtick(.5(.5)2, axis(1)) ymtick(0(5)90, axis(2))  ///
		   xlabel(0 "-10 to -5" 1 "-4" 2 "-3" 3 "-2" 4 "-1" 5 "0" 6 "1" 7 "2" 8 "3" 9 "4" 10 "5 to 10", labsize(small) axis(1)) ///
		   xlabel(${Mindexlab}, labsize(small) axis(2)) ///
		   xline(5, lcolor(gs12) lwidth(vthin) lpat(dash) axis(1)) ///
		   xtitle("", axis(2) size(medsmall)) xtitle("", axis(1) size(medsmall))  ytitle("", axis(1)) ytitle("", axis(2)) ///
		   legend(lab(7 "Husband's share") lab(3 "Husband's hours") lab(5 "Wife's hours") ///
					rows(3) order(5 3 7) ring(0) position(10) size(small) region(color(none))) ///
		   xsize(12) ysize(10) ///
		   text(0.5 4.8 "retired", xaxis(1) yaxis(1) placement(north) orientation(vertical) size(vsmall) color(gs12)) ///
		   scheme(lean1) graphregion(margin(zero)) ///
		   saving("${logDir}/Graph_Repairs", replace) name("Graph_Repairs", replace)
graph export "${logDir}/Graph_Repairs.pdf", name("Graph_Repairs") replace
// windows only 
capt graph export "${logDir}/Graph_Repairs.emf", name("Graph_Repairs") replace

restore

