/**********************************************************************
* 
* Leopold, Thomas and Skopek, Jan (2015). Convergence or Continuity? 
* The Gender Gap in Household Labor After Retirement. In: Journal of 
* Marriage and Family.
*
*
* Configuration file
* 
**********************************************************************/

clear				
//  version 13.1 		// stata version 13.1
capt log close _all	// close all log files


/******* Config *******/

global workingDir "`c(pwd)'"	// working directory (set to current working directory)

global data "../SOEPlong" // path to SOEP long files

global runimputation = 0 // set this to 1 if you want to re-run the imputation model. Otherwise the temporary file will be used.


/**********************/

/*** do not edit here ***/
global tempDir 		= "${workingDir}/temp"		// directory for temporary data files
global logDir		= "${workingDir}/log-files"	// directory for log files
global adoDir		= "${workingDir}/ado"
cd "$workingDir" 			// change to working directory
adopath + "$adoDir" 		// extend the ado-file search path
capt mkdir "$tempDir" 		// create directory for temporary files (if not there)
capt mkdir "$logDir" 		// create directory for log files (if not there)
/*** do not edit here (end) ***/

set varabbrev off	// turn off stata's akward feature of abbreviating variable names
set more off		// turn off the "more"
global config = 1	// a flag that config file was executed already


/*** programs ***/

// mi_meansd calculates mean and standard deviation as well as min and max values
//		for multiply imputed data.
capt program drop mi_meansd
program define mi_meansd 
	syntax varlist[, Format(passthru)]
	quiet {
	capt mat drop R 
	capt mat drop M
	* 1) estimate mean and standard deviation for varlist
	// Note: standard deviation in the context for multiply imputed data 
	//		 is calculated by sqrt(Var(x)) and Var(x) = E[x^2] - (E[x])^2	
	foreach var of varlist `varlist' {
		mi passive: gen __`var'__2 = `var'^2
		mi estimate, post: mean __`var'__2 `var' 
		
		local mean = _b[`var']
		local sd = sqrt(_b[__`var'__2] - `mean'^2)
		mat r = (`mean', `sd')
		
		drop __`var'__2
		mi update
		
		mat R = nullmat(R) \ r
		mat drop r
	}
	* 2) estimate min and max values for varlist 
	// Note: min and max values are calculated over all imputation data sets. 
	mi query 
	local M = `r(M)'
	foreach var of varlist `varlist' {
		local min = 0
		local max = 0
		foreach num of numlist 1/`M' {
			mi xeq `num': sum `var'
			if `num' == 1 {
				local min = `r(min)'
				local max = `r(max)'
			}
			if `r(min)' < `min' {
				local min = `r(min)'
			}
			if `r(max)' > `max' {
				local max = `r(max)'
			}
		}
		mat r = (`min', `max')
		mat M = nullmat(M) \ r
		mat drop r
	}
	
	mat R = R,M
	
	ds `varlist', varwidth(12)
	local varnames `r(varlist)'
	
	matname R `varnames', rows(.) 
	matname R mean sd min max, col(.) explicit
	
	noisily: matlist R, title("MI means and standard deviations (M = `M')") `format'
	
	capt mat drop R 
    capt mat drop r 
	capt mat drop M
	}
end 

* program to add additional model statistics to mi estimates
// note: mean over imputation datasets and add to the stored model estimates
// specify the stored results
capt program drop _mi_addstats
program define _mi_addstats
	quietly {
	args estimates
	est des `estimates' 
	mi xeq: `r(cmdline)'; gen e_r2 = e(r2); gen e_r2_w = e(r2_w); gen e_rho = e(rho)
	foreach var of varlist e_* {
		mi est, post: mean `var'
		local `var' = _b[`var']
		estadd scalar `var' = ``var'', replace: `estimates'
	}
	drop e_*
	}
end

* program calculating statistics on varying case numbers for the last mi estimation model 
capt program drop _mi_cases
program define _mi_cases
	quietly {
		mat N = e(N_vs_mi)
		mat N_g = e(N_g_vs_mi)
		capt mat N = N, N_g 
		clear
		svmat N
		rename N1 N
		capt rename N2 N_g
		mat drop N 
		capt mat drop N_g
	}
	
	capt sum N N_g
	if _rc > 0 {
		sum N
	}
	else {
		sum N N_g
	}
end

// helper programs for the fixed effects models
// Note: this is adjusted to model 2
capt program drop femargins
program femargins, eclass properties(mi)
  syntax anything [if]
  xtreg `anything' ${model2} `if', fe
  margins R2 , at(Feffworkhrs=0 cyard=0 chqm50=0 kind16=0 zMhlthsat=0 zFhlthsat=0 ) post
end

capt program drop hrsmargins
program define hrsmargins, rclass
	syntax [if], model(string) [at(passthru)]
	mi estimate, cmdok: femargins F`model' `if'	
	mat table = r(table)
	mat b = table[1,1..11]
	mat ci = table[5..6,1..11]
	mat F = b \ ci

	mi estimate, cmdok: femargins M`model' `if'		
	mat table = r(table)
	mat b = table[1,1..11]
	mat ci = table[5..6,1..11]
	mat M = b \ ci
	mat C = M \ F
	return matrix C = C
end

capt program drop shrmargins
program define shrmargins, rclass
	syntax [if]	, model(string) [at(passthru)]
	mi estimate, cmdok esampvaryok: femargins `model' `if'	
	mat table = r(table)
	mat b = table[1,1..11]
	mat ci = table[5..6,1..11]
	mat shr = (b \ ci)
	return matrix shr = shr
end


